function l2qa_bitextracter, MOD06FileName

;*************************************************************************
; Name: clm_bitextracter
;
; Purpose:
; l2qa_BitExtracter.pro extracts the individual QA flags from the full byte
;   array 1km QA and places the results into an output array.
;
; Input: 
;    MOD06FileName	String	   : Full path and name of the ecosystem ancillary file
; 
; Output:
;    QABitFlags 	Byte Array  : The individual results of the QA flags,
;				     written as follows:
;			L2QAFlags(*,*) = Cloud Phase used in retrieval proc. path
;
; Required Programs:
;  Read_Product_sds.pro
;
; Modification history:
;  11/08/2001
;    Initial Release.
;
; Credits:
;  Written by Eric G. Moody
;  eric.moody@gsfc.nasa.gov
;  Climate and Radiation Branch
;  NASA Goddard Space Flight Center
;  Greenbelt, Maryland, U.S.A.
;
; License:
; This software is provided "as-is", without any express or
; implied warranty. In no event will the authors be held liable
; for any damages arising from the use of this software.
;
; Permission is granted to anyone to use this software and to alter
; it freely, subject to the following restrictions:
;
; 1. The origin of this software must not be misrepresented; you must
;    not claim you wrote the original software.
;
; 2. Altered source versions must be plainly marked as such, and must
;    not be misrepresented as being the original software.
;
; 3. This notice may not be removed or altered from any source distribution.
;*************************************************************************


;Read in the QA, 1km:
MOD06FileID = HDF_SD_START(MOD06FileName,/READ)
Read_product_sds, L2QA, range, fillvalue, MOD06fileID, 'Quality_Assurance_1km', $
                  fail, /scaleNo, /offsetNo, /validrangeNo, /fillNo
HDF_SD_END, MOD06FileID


;Determine the size of the Cloud Mask array:
dims = size(L2QA,/dimensions)
xdim = dims(1)
ydim = dims(2)
nbands = dims(0)


;Transpose the array from band,x,y to x,y,band:
L2QA = TRANSPOSE(L2QA, [1, 2, 0])


;Create the integer L2QAFlags output array:
L2QAFlags = IntArr(xdim,ydim)

;Extract the Cloud Phase used in retrieval processing path:
L2QAFlags[*,*] =       (L2QA[*,*,2] AND   7B)


; Return the Extracted L2 QA Flags:
return, L2QAFlags

end
